<!----------------------------------------------------------------
	act_post.cfm

	Performs the database operations that actually add a new
	thread/post/reply, or edit a currently existing post. Mostly
	inherited from Simple Message Board's post.cfm.  See
	BlueBoard Notes.
------------------------------------------------------------------>

<!-- BlueBoard Note: Make sure that if the user was not entitled to
	 make the message a HotPost, that its HotPost status is false!
-->
<CFPARAM name="FORM.HotPost" default="#Bit_False#">

<!-- BlueBoard Note: Added "Admin" to user query, so we know user's
	 status.  Also, deleted password in 'WHERE' because it is
	 not necessary
-->
<CFQUERY NAME="GetPoster" DATASOURCE="#PrimaryDataSource#">
	SELECT UID, UserName, Password, Expand, ReverseSort, BPCount, CanPost, Signature, Admin,
		  (SELECT COUNT(*) FROM Moderators WHERE Moderators.FID = #FORM.FID# AND Moderators.UID = Users.UID) AS IsModerator
	  FROM Users 
	 WHERE UserName = '#Cookie.Username#'
</CFQUERY>

<CFIF FORM.Edit> <!--- Get the MID for the Message being Edited --->
	<CFQUERY NAME="GetMessage" DATASOURCE="#PrimaryDataSource#">
		SELECT UID FROM Messages WHERE MID = #FORM.MID#
	</CFQUERY>
</CFIF>

<CFIF NOT GetPoster.RecordCount>
	<CFSET Error = "Sorry, Incorrect UserName and/or Password.">

<!-- BlueBoard Note: The following two checks are no longer necessary,
	 we have done away with brownie points and posting privilages
<CFELSEIF BP_On AND (GetPoster.BPCount LT BP_Post)>
	<CFSET Error = "Sorry, you do not have enough #BP_String#s to post.">
<CFELSEIF NOT GetPoster.CanPost>
	<CFSET Error = "Sorry, you do not have posting privileges.">
-->

<!-- BlueBoard Note: Added admin check here - admins should be
	 able to edit anyone's message -->
<CFELSEIF FORM.Edit AND NOT (GetPoster.Admin OR GetPoster.UID EQ GetMessage.UID)>
	<CFSET Error = "Sorry, you cannot edit this message.">
<CFELSE>

	<!--- Set Cookies --->

	<!-- BlueBoard Note: The cookies have been changed slightly for our system:
		 - "UID" "Username" "Password" fields have had their "expires"
		   attributes removed so that they expire when the browser is
		   closed.
		 - "Admin" cookie added, again with no expiration specified.
	-->
	<CFCOOKIE NAME="UID" VALUE="#GetPoster.UID#" DOMAIN="#PrimaryCookieDomain#">
	<CFCOOKIE NAME="Username" VALUE="#GetPoster.Username#" DOMAIN="#PrimaryCookieDomain#">
	<CFCOOKIE NAME="Password" VALUE="#ENCRYPT(GetPoster.Password,CryptKey)#" DOMAIN="#PrimaryCookieDomain#">
	<CFCOOKIE NAME="Admin" VALUE="#YesNoFormat(GetPoster.Admin)#" DOMAIN="#PrimaryCookieDomain#">
	<CFCOOKIE NAME="Expand" VALUE="#GetPoster.Expand#" DOMAIN="#PrimaryCookieDomain#" EXPIRES="60">
	<CFCOOKIE NAME="ReverseSort" VALUE="#GetPoster.ReverseSort#" DOMAIN="#PrimaryCookieDomain#" EXPIRES="60">

	<!--- Process --->
	<CFSET RightNow = Now()>
	<CFTRANSACTION>
		<CFIF IsDefined('FORM.Delete')>
			<CFQUERY NAME="CheckThread" DATASOURCE="#PrimaryDataSource#">
				SELECT COUNT(MID) AS MCount FROM Messages WHERE TID = #TID#
			</CFQUERY>
			<CFQUERY NAME="DeleteMessage" DATASOURCE="#PrimaryDataSource#">
				DELETE FROM Messages WHERE MID = #MID#
			</CFQUERY>
			<CFIF CheckThread.MCount EQ 1><!--- Last Message in Thread --->
				<CFQUERY NAME="DeleteThread" DATASOURCE="#PrimaryDataSource#">
					DELETE FROM Threads WHERE TID = #TID#
				</CFQUERY>
			<CFELSE>
				<CFQUERY NAME="UpdateThread" DATASOURCE="#PrimaryDataSource#">
					UPDATE Threads SET MCount = MCount - 1 WHERE TID = #TID#
				</CFQUERY>
			</CFIF>
			<CFQUERY NAME="UpdateForums" DATASOURCE="#PrimaryDataSource#">
        		UPDATE Forums SET <CFIF CheckThread.MCount EQ 1>TCount = TCount - 1,</CFIF> MCount = MCount - 1 WHERE FID = #FID#
		    </CFQUERY>
			<CFSET ThisThread = TID>
		<CFELSE>
			<CFIF NOT FORM.TID> <!--- Create New Thread --->
				<CFQUERY NAME="CreateThread" DATASOURCE="#PrimaryDataSource#">
			        INSERT INTO Threads (FID, Thread, StartDate, StartDate_UID, LastPost, MCount, Status) 
			        VALUES (#FORM.FID#, '#FORM.Subject#', #RightNow#, #GetPoster.UID#, #RightNow#, 1, 0)
			    </CFQUERY>
				<CFQUERY NAME="NewThread" DATASOURCE="#PrimaryDataSource#">
			        SELECT MAX(TID) AS NewID FROM Threads
			    </CFQUERY>
				<CFSET ThisThread = NewThread.NewID>
			<CFELSE> <!--- Or Not --->
				<CFQUERY NAME="UpdateThreads" DATASOURCE="#PrimaryDataSource#">
			        UPDATE Threads SET <CFIF NOT FORM.Edit>MCount = MCount + 1, LastPost_UID = #GetPoster.UID#, </CFIF>LastPost = #RightNow#
			         WHERE TID = #FORM.TID#
		    	</CFQUERY>
				<CFSET ThisThread = FORM.TID>
			</CFIF>
			<CFIF FORM.Edit> <!--- Edit Message --->
				<!-- BlueBoard Note: Edited "edited by" message to not be in HTML -->
				<CFSET Message = FORM.Message & "#Chr(10)##Chr(13)#[Edited by #TRIM(GetPoster.Username)# on #DateFormat(RightNow, '#DateMask#')# #TimeFormat(RightNow, '#TimeMask#')#]#Chr(10)##Chr(13)#">
				<!-- BlueBoard Note: Edited this query to be sure it inserts
					 HotPost information into the db -->
				<CFQUERY NAME="UpdateMessage" DATASOURCE="#PrimaryDataSource#">
			        UPDATE Messages SET Subject = '#FORM.Subject#', Message = '#Message#', HotPost = '#FORM.HotPost#'
					 WHERE MID = #FORM.MID#
			    </CFQUERY>
			<CFELSE> <!--- New Message --->
				<!-- BlueBoard Note: Edited this query to be sure it inserts
					 HotPost information into the db -->
				<CFQUERY NAME="PostMessage" DATASOURCE="#PrimaryDataSource#">
			        INSERT INTO Messages (TID, UID, Subject, Message, PostDate, Indent, RemoteIP, BP<CFIF FORM.MID>, ReplyTo</CFIF>, UseSig, SendMail, HotPost) 
			        VALUES (#ThisThread#, #GetPoster.UID#, '#Form.Subject#', '#Form.Message#', 
							#RightNow#, 0, '#CGI.REMOTE_ADDR#', 0<CFIF FORM.MID>, #Form.MID#</CFIF>, #UseSig#, #Bit_False#, #HotPost#)
			    </CFQUERY>
				<CFQUERY NAME="UpdateUsers" DATASOURCE="#PrimaryDataSource#">
			        UPDATE Users SET MCount = MCount + 1 WHERE UID = #GetPoster.UID#
			    </CFQUERY>
			</CFIF>
			<CFQUERY NAME="UpdateForums" DATASOURCE="#PrimaryDataSource#">
		        UPDATE Forums SET <CFIF NOT FORM.Edit><CFIF NOT FORM.TID>TCount = TCount + 1, </CFIF>MCount = MCount + 1, </CFIF> LastPost = #RightNow#
				WHERE FID = #FID#
		    </CFQUERY>
		</CFIF>
	</CFTRANSACTION>

	<CFOUTPUT><TR><TD BGCOLOR="#Clr_BG4#"><B>Message #FORM.Subject# <CFIF IsDefined('FORM.Delete')>Deleted<CFELSEIF Edit>Edited<CFELSE>Posted</CFIF>:</B> <A HREF="#MB_Dir#/index.cfm?Fuseaction=ShowThread&TID=#ThisThread#">Back to Thread</A><BR><I>(Please stand by, you will be automatically redirected.)</I></TD></TR></CFOUTPUT>
	<CFHTMLHEAD TEXT='<META HTTP-EQUIV="Refresh" CONTENT="2;URL=#MB_Dir#/index.cfm?Fuseaction=ShowThread&TID=#ThisThread#">'>

</CFIF>

<CFIF IsDefined('Error')>
	<CFOUTPUT><TR><TD BGCOLOR="#Clr_BG4#"><B><FONT COLOR="#Clr_Error#">#Error#</FONT></B></TD></TR></CFOUTPUT>
</CFIF>
